@@ -62,22 +62,19 @@ tabs::tabs(KRenameImpl* impl, QRect r, QWidget *parent, const char *name )
     
     connect( cancelButton, SIGNAL( clicked() ), this, SLOT( close() ) );
 
-    if( impl ) {
-        krename = impl;
-        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
+    krename = impl ? impl : new KRenameImpl( this, menuBar, finishButton );
 
-        krename->changeParent( this, menuBar, finishButton, r );
-        krename->setWizardMode( false );
-    } else {
-        krename = new KRenameImpl( this, menuBar, finishButton );
-        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
-
-        krename->setup( false );
-    }
-    
+    connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
     connect( krename, SIGNAL( showPage( int ) ), this, SLOT( slotShowPage( int ) ) );
     connect( krename, SIGNAL( enableFinish( bool ) ), this, SLOT( slotEnableFinish( bool ) ) );
     connect( tab, SIGNAL( currentChanged( QWidget* ) ), this, SLOT( slotTabChanged() ) );
+    
+    if( impl ) 
+    {
+        krename->changeParent( this, menuBar, finishButton, r );
+        krename->setWizardMode( false );
+    } else 
+        krename->setup( false );
 
     // Tell KStartupInfo that KRename has been loaded completly
     KStartupInfoId id;
